@@ -30,7 +30,7 @@ has screenOpts => sub {
     my $self = shift;
     my $opts = $self->SUPER::screenOpts;
     return {
-        %$opts,
+        %%$opts,
         # an alternate layout for this screen
         layout => {
             class => 'qx.ui.layout.Dock',
@@ -39,6 +39,8 @@ has screenOpts => sub {
         # and settings accordingly
         container => {
             set => {
+                # see https://www.qooxdoo.org/apps/apiviewer/#qx.ui.core.LayoutItem
+                # for inspiration in properties to set
                 maxWidth => 700,
                 maxHeight => 500,
                 alignX => 'left',
